#
# spec file for package python-pyqtgraph
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with    test
Name:           python-pyqtgraph
Version:        0.10.0
Release:        lp151.1.2
Summary:        Scientific Graphics and GUI Library for Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://www.pyqtgraph.org/
Source:         https://files.pythonhosted.org/packages/source/p/pyqtgraph/pyqtgraph-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module qt5 >= 5.5}
BuildRequires:  %{python_module scipy >= 0.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-numpy
Requires:       python-opengl
Requires:       python-qt5
Requires:       python-scipy
BuildArch:      noarch

%python_subpackages

%description
PyQtGraph is a pure-python graphics and GUI library built on 
PyQt4 / PySide and numpy. It is intended for use in 
mathematics / scientific / engineering applications. 

Despite being written entirely in python, it leverages numpy for
number crunching and Qt's GraphicsView framework for display.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Python
Provides:       %{python_module %{name} = %{version}}

%description -n %{name}-doc
Documentation and help files for %{name}

%prep
%setup -q -n pyqtgraph-%{version}
chmod a+x examples/*.py

%build
%python_build

%install
%python_install

pushd doc
make html
rm build/html/.buildinfo build/doctrees/environment.pickle
popd

mkdir -p %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/html %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/doctrees %{buildroot}%{_docdir}/%{name}/
cp -r examples %{buildroot}%{_docdir}/%{name}/

for f in MultiPlotSpeedTest MultiPlotWidget PlotSpeedTest ROItypes ScatterPlotSpeedTest ViewBox infiniteline_performance ; do
    %{python_expand chmod a+x %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/python$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/python -i$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    }
    sed -i "s|^#!/usr/bin/env python$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
    sed -i "s|^#!/usr/bin/python$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
    sed -i "s|^#!/usr/bin/python -i$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
done
%{python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyqtgraph/examples/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pyqtgraph/examples/
%fdupes %{buildroot}%{$python_sitelib}
}

%fdupes %{buildroot}%{_docdir}/%{name}/

%if %{with test}
%check
%python_expand py.test-%{$python_bin_suffix}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%license LICENSE.txt
%exclude %{_docdir}/%{name}/doctrees/
%exclude %{_docdir}/%{name}/examples/
%exclude %{_docdir}/%{name}/html/
%{python_sitelib}/pyqtgraph/
%{python_sitelib}/pyqtgraph-%{version}-py*.egg-info

%files -n %{name}-doc
%defattr(-,root,root,-)
%license LICENSE.txt
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/doctrees/
%{_docdir}/%{name}/examples/
%{_docdir}/%{name}/html/

%changelog
* Fri May 18 2018 jengelh@inai.de
- Trim bias from description.
* Thu May 17 2018 bwiedemann@suse.com
- Drop environment.pickle from rpm to make build reproducible
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Tue Aug 22 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix rpmlint issues
- Fix shebangs
* Mon Nov  7 2016 termim@gmail.com
- Update to 0.10.0
  * New Features:
  - PyQt5 support
  - Options for interpreting image data as either row-major or col-major
  - InfiniteLine and LinearRegionItem can have attached labels
  - DockArea:
  - Dock titles can be changed after creation
  - Added Dock.sigClosed
  - Added TextItem.setColor()
  - FillBetweenItem supports finite-connected curves (those that exclude
    nan/inf)
  * API / behavior changes:
  - Improved ImageItem performance for some data types by scaling LUT
    instead of image
  - Change the defaut color kwarg to None in TextItem.setText() to avoid
    changing the color every time the text is changed.
  - FFT plots skip first sample if x-axis uses log scaling
  - Multiprocessing system adds bytes and unicode to the default list of
    no-proxy data types
  - Version number scheme changed to be PEP440-compliant (only affects
    installations from non-release git commits)
  * Bugfixes:
  - Fix for numpy API change that caused casting errors for inplace operations
  - Fixed git version string generation on python3
  - Fixed setting default values for out-of-bound points in
    pg.interpolateArray
  - Fixed plot downsampling bug on python 3
  - Fixed invalid slice in ImageItem.getHistogram
  - DockArea:
  - Fixed adding Docks to DockArea after all Docks have been removed
  - Fixed DockArea save/restoreState when area is empty
  - Properly remove select box when export dialog is closed using window
    decorations
  - Remove all modifications to python builtins
  - Better Python 2.6 compatibility
  - Fix SpinBox decimals
  - Fixed numerous issues with ImageItem automatic downsampling
  - Fixed PlotItem average curves using incorrect stepMode
  - Fixed TableWidget eating key events
  - Prevent redundant updating of flowchart nodes with multiple inputs
  - Ignore wheel events in GraphicsView if mouse interaction is disabled
  - Correctly pass calls to QWidget.close() up the inheritance chain
  - ColorMap forces color inputs to be sorted
  - Fixed memory mapping for RemoteGraphicsView in OSX
  - Fixed QPropertyAnimation str/bytes handling
  - Fixed __version__ string update when using `setup.py install` with
    newer setuptools
  * Maintenance:
  - Image comparison system for unit testing plus tests for several
    graphics items
  - Travis CI and coveralls/codecov support
  - Add examples to unit tests
* Fri Dec 11 2015 mardnh@gmx.de
- Update to version 0.9.10
  * No changelog available
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Remove useless CFLAGS definition
- README.txt is not provided anymore by upstream
* Sat Apr 20 2013 toddrme2178@gmail.com
- Remove unneeded python(abi) requires
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 0.9.7
  * No changelog
- Add python 3 version
* Thu Nov 29 2012 toddrme2178@gmail.com
- Initial spec file
